@@ -232,31 +232,32 @@ print.decorated_ggplot <- function(
   for(i in seq_along(x$labels)){           # x (gg object) stores names of used columns as $labels
     lab <- x$labels[[i]]                   # handle one label
     if(length(lab)){                       # i.e. not null or empty expression
-      if(lab %in% names(x$data)){            # if this is just a bare column name
-        col <- x$data[[lab]]
-        atr <- attributes(col)
-        for( s in rev(search)){              # end with first
-          label <- atr[[s]]                  # retrieve label
-          if(!is.null(label)){
-            x$labels[[i]] <- label           # overwrite default label with one from data attributes
+      if(length(lab) == 1){
+        if(lab %in% names(x$data)){            # if this is just a bare column name
+          col <- x$data[[lab]]
+          atr <- attributes(col)
+          for( s in rev(search)){              # end with first
+            label <- atr[[s]]                  # retrieve label
+            if(!is.null(label)){
+              x$labels[[i]] <- label           # overwrite default label with one from data attributes
+            }
           }
-        }
-        # done with search.  Plural labels?
-        if(length(x$labels[[i]]) > 1){
-          labs <- x$labels[[i]]
-          if(length(names(labs)))labs = paste(
-            paste0(
-              '(',
-              names(labs),
-              ')'
-            ),
-            labs
-          )
-          labs <- paste(labs, collapse = '\n')
-          msg <- paste('using first of', labs, sep = '\n')
-          warning(msg)
-          x$labels[[i]] <- x$labels[[i]][[1]]
-        }
+        } 
+      }
+      # done with search.  Plural labels? Note x$labels unchanged, lab unchanged
+      if(length(lab) > 1){
+        if(length(names(lab)))lab = paste(
+          paste0(
+            '(',
+            names(lab),
+            ')'
+          ),
+          lab
+        )
+        lab <- paste(lab, collapse = '\n')
+        msg <- paste('using first of', lab, sep = '\n')
+        warning(msg)
+        x$labels[[i]] <- x$labels[[i]][[1]]
       }
     }
   }
